@@ -62,7 +62,7 @@ class DescribeMonitorGroupsRequest(RpcRequest):
 		self.add_query_param('PageSize',PageSize)
 
 	def get_Tags(self):
-		return self.get_query_params().get('Tags')
+		return self.get_query_params().get('Tag')
 
 	def set_Tags(self, Tags):
 		for depth1 in range(len(Tags)):
