@@ -25,12 +25,6 @@ class ModifyHostInfoRequest(RpcRequest):
 		RpcRequest.__init__(self, 'Cms', '2019-01-01', 'ModifyHostInfo','cms')
 		self.set_method('POST')
 
-	def get_IP(self):
-		return self.get_query_params().get('IP')
-
-	def set_IP(self,IP):
-		self.add_query_param('IP',IP)
-
 	def get_HostName(self):
 		return self.get_query_params().get('HostName')
 
